pub struct ConfiguredClient<C> { /* private fields */ }Expand description
A client with ClientOptions attached, which can be passed to initialize workers, or can be used directly. Is cheap to clone.
Implementations
Sourceimpl<C> ConfiguredClient<C>
impl<C> ConfiguredClient<C>
Sourcepub fn set_headers(&self, headers: HashMap<String, String>)
pub fn set_headers(&self, headers: HashMap<String, String>)
Set HTTP request headers overwriting previous headers
Sourcepub fn set_api_key(&self, api_key: Option<String>)
pub fn set_api_key(&self, api_key: Option<String>)
Set API key, overwriting previous
Sourcepub fn options(&self) -> &ClientOptions
pub fn options(&self) -> &ClientOptions
Returns the options the client is configured with
Sourcepub fn capabilities(&self) -> Option<&Capabilities>
pub fn capabilities(&self) -> Option<&Capabilities>
Returns the server capabilities we (may have) learned about when establishing an initial connection
Sourcepub fn workers(&self) -> Arc<SlotManager>
pub fn workers(&self) -> Arc<SlotManager>
Returns a cloned reference to a registry with workers using this client instance